autowisp.processing_steps.measure_aperture_photometry module — AutoWISP documentation

# autowisp.processing_steps.measure_aperture_photometry module

## Class Inheritance Diagram

Perform aperture photometry on a set of frames in parallel.

autowisp.processing_steps.measure_aperture_photometry.cleanup_interrupted(interrupted, configuration)

  Remove the aperture photometry from a frame that was interrupted.

autowisp.processing_steps.measure_aperture_photometry.get_photometer(configuration)

  Create an instance of SubPixPhot ready to be applied.

  Parameters:

    configuration (dict) – The configuration specifying how to run photometry.

  Returns:

    A fully configured instance ready to carry out photometry as specified by the given configuration.

  Return type:

    SubPixPhot

autowisp.processing_steps.measure_aperture_photometry.has_psf_model(image_fname, shapefit_version)

  Check if the DR file contains a sky-to-frame transformation.

autowisp.processing_steps.measure_aperture_photometry.main()

  Run the step from the command line.

autowisp.processing_steps.measure_aperture_photometry.measure_aperture_photometry(image_collection, start_status, configuration, mark_start, mark_end)

  Extract aperture photometry from the given images.

autowisp.processing_steps.measure_aperture_photometry.parse_command_line(*args)

  Return the parsed command line arguments.

autowisp.processing_steps.measure_aperture_photometry.photometer_frame(frame_fname, configuration, mark_start, mark_end)

  Perform aperture photometry on a single frame.